###################################################
### chunk number 1: 
###################################################
library(iSubpathwayMiner)


###################################################
### chunk number 2: 
###################################################
#get path of the KGML files
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/metabolic/ec/",sep="")
#convert pathways to a list in R
pList<-getPathway(path,c("ec00010.xml","ec00020.xml"))
#convert metabolic pathways to graphs
gmList<-getMetabolicGraph(pList)


###################################################
### chunk number 3: overview1
###################################################
#visualize
plotGraph(gmList[[1]])


###################################################
### chunk number 4: 
###################################################
getOrgAndIdType()


###################################################
### chunk number 5: 
###################################################
#To do this, let us generate an example of gene sets:
geneList<-getExample(geneNumber=1000,compoundNumber=0)
#see a part of the set. 
#organism:human (hsa)
#identifier type:Entrez Gene IDs (ncbi-geneid)
geneList[1:5]
#annotate the sets to pathways 
#evaluate the enrichment significance of pathways
ann<-identifyGraph(geneList,gmList)
#print the results to screen
printGraph(ann)


###################################################
### chunk number 6: 
###################################################
#get path of the KGML files
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/metabolic/ec/",sep="")
#convert pathways to a list in R
p<-getPathway(path,c("ec00010.xml","ec00020.xml"))
#see type of the variable p
typeof(p)
#see length of the variable p
length(p)


###################################################
### chunk number 7: 
###################################################
#display information stored in the variable p
p[[1]][1]
#the first entry information of the pathway
p[[1]][[2]][1]
#the first relation information of the pathway
p[[1]][[3]][1]
#the first reaction information of the pathway
p[[1]][[4]][1]


###################################################
### chunk number 8: 
###################################################
#get path of the KGML files
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/metabolic/ec/",sep="")
#convert pathways to a list in R
p<-getPathway(path,c("ec00010.xml","ec00020.xml"))
#convert metabolic pathways to graphs
gm<-getMetabolicGraph(p)


###################################################
### chunk number 9: getMetabolicGraph1
###################################################
#name of graph gm[[1]]
gm[[1]]$title
#visualize
plotGraph(gm[[1]])


###################################################
### chunk number 10: 
###################################################
summary(gm[[1]])


###################################################
### chunk number 11: 
###################################################
print(gm[["00010"]],v=TRUE,e=TRUE,g=TRUE)


###################################################
### chunk number 12: 
###################################################
#display a subgraph with 5 nodes.
sgm<-subgraph(gm[[1]],V(gm[[1]])[1:5])
print(sgm,g=TRUE,v=TRUE,e=TRUE)


###################################################
### chunk number 13: 
###################################################
gm[[1]]$title
gm[[1]]$number


###################################################
### chunk number 14: 
###################################################
V(gm[[1]])[2]$names


###################################################
### chunk number 15: 
###################################################
get.vertex.attribute(gm[[1]],"names",2)


###################################################
### chunk number 16: 
###################################################
V(gm[[1]])[2]$type


###################################################
### chunk number 17: 
###################################################
#get indexes of nodes
index1<-V(gm[[1]])[V(gm[[1]])$names=="ec:4.1.2.13"]
index2<-V(gm[[1]])[V(gm[[1]])$names=="ec:1.2.1.59"]
#get shortest path
shortest.path<-get.shortest.paths(gm[[1]],index1,index2)
#display shortest path
shortest.path
#convert indexes to names
V(gm[[1]])[shortest.path[[1]]]$names


###################################################
### chunk number 18: 
###################################################
index1<-V(gm[[1]])[V(gm[[1]])$names=="ec:4.1.2.13"]
betweenness(gm[[1]],index1)


###################################################
### chunk number 19: 
###################################################
#node index value
as.integer(index1)
#direct display is not real node index value.
index1
#it is equal to the value of the "id" attribute.
index1$id


###################################################
### chunk number 20: getNonMetabolicGraph1
###################################################
#get path
pathn<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/non-metabolic/ko/",sep="")
pn<-getPathway(pathn,c("ko04010.xml","ko04020.xml"))
#Convert pathways to graphs
gn1<-getNonMetabolicGraph(pn)
#name of the first pathway
gn1[[1]]$title
#visualize
plotGraph(gn1[[1]])


###################################################
### chunk number 21: getNonMetabolicGraph2
###################################################
#Convert pathways to graphs with ambiguous edges as deleted
gn2<-getNonMetabolicGraph(pn,ambiguousEdgeDirection="delete")
#visualize
plotGraph(gn2[[1]])


###################################################
### chunk number 22: 
###################################################
##get metabolic pathway graphs
#get path of KGML files
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/metabolic/ec/",sep="")
#convert metabolic pathways to graphs
gm<-getMetabolicGraph(getPathway(path,c("ec00010.xml")))
#show title of pathway graphs
sapply(gm,function(x) x$title)

##get non-metabolic pathway graphs
#get path
path1<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/non-metabolic/ko/",sep="")
#convert non-metabolic pathways to graphs
gn<-getNonMetabolicGraph(getPathway(path1,c("ko04010.xml","ko04020.xml")),
ambiguousEdgeDirection="bi-directed")
#show title of pathway graphs
sapply(gn,function(x) x$title)


###################################################
### chunk number 23: getUGraph
###################################################
#get undirected pathway graphs
g1<-getUGraph(gm,simpleGraph=TRUE)
#visualzie an undirected graph
plotGraph(g1[[1]])


###################################################
### chunk number 24: 
###################################################
getOrgAndIdType()


###################################################
### chunk number 25: mapNode
###################################################
#see the names attribute of nodes. 
V(gm[[1]])[1:10]$names
#get the organism-specific and idType-specific graph
g1<-mapNode(gm)
#see the names attribute of nodes in the new graph. 
#some node names are revised as NCBI-gene IDs 
V(g1[[1]])[1:10]$names
#visualize the Glycolysis / Gluconeogenesis pathway graph
plotGraph(g1[[1]])


###################################################
### chunk number 26: filterNode
###################################################
#We display them before nodes are filtered
V(gn[[1]])$type
#delete nodes with type="map"
g1<-filterNode(gn,nodeType=c("map"))
#The "map" nodes are deleted in the new graph. 
V(g1[[1]])$type
#visulize the graph
plotGraph(g1[[1]])


###################################################
### chunk number 27: 
###################################################
g2<-filterNode(gn,nodeType=c("compound","map"))


###################################################
### chunk number 28: simplifyGraphGene
###################################################
#get graphs with enzymes as nodes and compounds as edges
g1<-simplifyGraph(gm,nodeType="geneProduct")
#see the names attribute of three edges
E(g1[[1]])[1:3]$names
#visualize a graph
plotGraph(g1[[1]],edge.label=E(g1[[1]])[1:3]$names)


###################################################
### chunk number 29: simplifyGraphCompound
###################################################
#get graphs with compounds as nodes and enzymes as edges
g2<-simplifyGraph(gm,nodeType="compound")
#see the names attribute of three edges
E(g2[[1]])[1:3]$names
#visualize a graph
plotGraph(g2[[1]],edge.label=E(g2[[1]])[1:3]$names)


###################################################
### chunk number 30: simplifyNonNew
###################################################
#get the graph with gene products as nodes. 
#Edges contain direct and indirect edges
g3<-simplifyGraph(gn,nodeType="geneProduct",directEdge=TRUE)
#visualize the new graph
plotGraph(g3[[2]])


###################################################
### chunk number 31: simplifyNonOld
###################################################
#graph before conversion
#see pathway name
gn[[2]]$title
#visualize
plotGraph(gn[[2]])


###################################################
### chunk number 32: 
###################################################
#We firstly display node number before nodes are expanded
vcount(gn[[1]])
##expand nodes in Graphs
g1<-expandNode(gn)
#We can see change of node number in the new graph:
#node number after nodes are expanded
vcount(g1[[1]])


###################################################
### chunk number 33: expandNode1
###################################################
plotGraph(g1[[1]],layout=layout.sphere)


###################################################
### chunk number 34: 
###################################################
#only expand nodes with type="enzyme" or "ortholog" in graphs
g2<-expandNode(gn,nodeType=c("ortholog","enzyme"))


###################################################
### chunk number 35: 
###################################################
all(sapply(gm,is.simple))


###################################################
### chunk number 36: mergeNode
###################################################
#get node number before merge
vcount(gm[[1]])
#merge nodes
g1<-mergeNode(gm,simple=FALSE)
#get node number after merge
vcount(g1[[1]])
#visualize
plotGraph(g1[[1]])


###################################################
### chunk number 37: combination1-1
###################################################
#get graphs with enzymes and compounds as nodes
g1<-filterNode(gm,nodeType=c("map"))
#visualize
plotGraph(g1[[1]])


###################################################
### chunk number 38: combination1-2
###################################################
#get the undirected graphs with enzymes and compounds as nodes
g2<-filterNode(getUGraph(gm),nodeType=c("map"))
#visualize
plotGraph(g2[[1]])


###################################################
### chunk number 39: combination1-3
###################################################
#get graphs with enzymes and compounds as nodes
#And, each node only contains one enzyme/compound and 
#each enzyme/compound only appears once in the graph.
g3<-mergeNode(expandNode(filterNode(gm,nodeType=c("map"))))
#visualize
plotGraph(g3[[1]])


###################################################
### chunk number 40: combination1-4
###################################################
#get the undirected graphs with enzymes and compounds as nodes
#And, each node only contains one enzyme/compound and 
#each enzyme/compound only appears once in the graph.
g4<-mergeNode(expandNode(filterNode(getUGraph(gm),nodeType=c("map"))))
#visualize
plotGraph(g4[[1]])


###################################################
### chunk number 41: combination1-5
###################################################
#get graphs with KOs and compounds as nodes
g5<-filterNode(gn,nodeType=c("map"))
#visualize
plotGraph(g5[[1]])


###################################################
### chunk number 42: combination1-6
###################################################
#get the undirected graphs with KOs and compounds as nodes
g6<-filterNode(getUGraph(gn),nodeType=c("map"))
#visualize
plotGraph(g6[[1]])


###################################################
### chunk number 43: combination1-7
###################################################
#get graphs with KOs and compounds as nodes
#And, each node only contains a KO/compound and 
#each KO/compound only appears once in the graph.
g7<-mergeNode(expandNode(filterNode(gn,nodeType=c("map"))))
#visualize
plotGraph(g7[[1]],layout=layout.sphere)


###################################################
### chunk number 44: combination1-8
###################################################
#get the undirected graphs with KOs and compounds as nodes
#And, each node only contains a KO/compound and 
#each KO/compound only appears once in the graph.
g8<-mergeNode(expandNode(filterNode(getUGraph(gn),nodeType=c("map"))))
#visualize
plotGraph(g8[[1]],layout=layout.sphere)


###################################################
### chunk number 45: combination2-1
###################################################
#get graphs with enzymes as nodes and compounds as edges
g1<-simplifyGraph(filterNode(gm,nodeType=c("map")),nodeType="geneProduct")
#visualize
plotGraph(g1[[1]])


###################################################
### chunk number 46: combination2-2
###################################################
#get the undirected graphs with enzymes as nodes and compounds as edges
g2<-simplifyGraph(filterNode(getUGraph(gm),nodeType=c("map")),nodeType="geneProduct")
#visualize
plotGraph(g2[[1]])


###################################################
### chunk number 47: combination2-3
###################################################
#get graphs with enzymes as nodes and compounds as edges
#And, each node contains only one enzyme and each enzyme only appears once. 
g3<-mergeNode(expandNode(simplifyGraph(filterNode(gm,
nodeType=c("map")),nodeType="geneProduct")))
#visualize
plotGraph(g3[[1]])


###################################################
### chunk number 48: combination2-4
###################################################
#get undirected graphs with enzymes as nodes and compounds as edges.
#And, each node contains only one enzyme and each enzyme only appears once. 
g4<-mergeNode(expandNode(simplifyGraph(filterNode(getUGraph(gm),
nodeType=c("map")),nodeType="geneProduct")))
#visualize
plotGraph(g4[[1]])


###################################################
### chunk number 49: combination2-5
###################################################
#get graphs with KOs as nodes
g5<-simplifyGraph(filterNode(gn,nodeType=c("map")),nodeType="geneProduct")
#visualize
plotGraph(g5[[1]])


###################################################
### chunk number 50: combination2-6
###################################################
#get the undirected graphs with KOs as nodes
g6<-simplifyGraph(filterNode(getUGraph(gn),
nodeType=c("map")),nodeType="geneProduct")
#visualize
plotGraph(g6[[1]])


###################################################
### chunk number 51: combination2-7
###################################################
#get graphs with only KOs as nodes. And, each node contains 
#only a KO and each KO only appears once in the graph.
g7<-mergeNode(expandNode(simplifyGraph(filterNode(gn,
nodeType=c("map")),nodeType="geneProduct")))
#visualize
plotGraph(g7[[1]],layout=layout.sphere)


###################################################
### chunk number 52: combination2-8
###################################################
#get the undirected graphs with only KOs as nodes. And, each node contains 
#only a KO and each KO only appears once in the graph.
g8<-mergeNode(expandNode(simplifyGraph(filterNode(gn,
nodeType=c("map")),nodeType="geneProduct")))
#visualize
plotGraph(g8[[1]],layout=layout.sphere)


###################################################
### chunk number 53: combination3-1
###################################################
#The graph with compounds as nodes and enzymes as edges
g1<-simplifyGraph(filterNode(gm,nodeType=c("map")),nodeType="compound")
#visualize
plotGraph(g1[[1]])


###################################################
### chunk number 54: combination3-2
###################################################
#The undirected graph with compounds as nodes and enzymes as edges
g2<-simplifyGraph(filterNode(getUGraph(gm),nodeType=c("map")),nodeType="compound")
#visualize
plotGraph(g2[[1]])


###################################################
### chunk number 55: combination3-3
###################################################
#The graph with compounds as nodes and enzymes as edges
#Each node only contains a compound and each compound only appears once in the graph.
g3<-mergeNode(expandNode(simplifyGraph(filterNode(gm,
nodeType=c("map")),nodeType="compound")))
#visualize
plotGraph(g3[[1]])


###################################################
### chunk number 56: combination3-4
###################################################
#The undirected graph with compounds as nodes and enzymes as edges
#Each node only contains a compound and each compound only appears once in the graph.
g4<-mergeNode(expandNode(simplifyGraph(filterNode(getUGraph(gm),
nodeType=c("map")),nodeType="compound")))
#visualize
plotGraph(g4[[1]])


###################################################
### chunk number 57: combination4-1
###################################################
#get graphs with organism-specific genes as nodes and compounds as edges
g1<-mergeNode(expandNode(simplifyGraph(filterNode(mapNode(gm),
nodeType=c("map","enzyme")),nodeType="geneProduct")))
#visualize
plotGraph(g1[[1]],layout=layout.sphere)


###################################################
### chunk number 58: combination4-2
###################################################
#get the undirected graphs with organism-specific genes as nodes and compounds as edges
g2<-mergeNode(expandNode(simplifyGraph(filterNode(mapNode(getUGraph(gm)),
nodeType=c("map","enzyme")),nodeType="geneProduct")))
#visualize
plotGraph(g2[[1]],layout=layout.sphere)


###################################################
### chunk number 59: combination4-3
###################################################
#get graphs with organism-specific genes as nodes
g3<-mergeNode(expandNode(simplifyGraph(filterNode(mapNode(gn),
nodeType=c("map","ortholog")),nodeType="geneProduct")))
#visualize
plotGraph(g3[[1]],layout=layout.sphere)


###################################################
### chunk number 60: combination4-4
###################################################
#get the undirected graphs with organism-specific genes as nodes
g4<-mergeNode(expandNode(simplifyGraph(filterNode(mapNode(gn),
nodeType=c("map","ortholog")),nodeType="geneProduct")))
#visualize
plotGraph(g4[[1]],layout=layout.sphere)


###################################################
### chunk number 61: 
###################################################
#get path of KGML files
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/metabolic/ec/",sep="")
#convert metabolic pathways to graphs with "map" node deleted
gmf<-filterNode(getMetabolicGraph(getPathway(path,c("ec00010.xml"))))
#show title of pathway graphs
sapply(gmf,function(x) x$title)
#convert metablic pathways to graphs with enzymes as nodes and compounds as edges
gmfs<-simplifyGraph(gmf,nodeType="geneProduct")


###################################################
### chunk number 62: baseGraph2
###################################################
#visualize annotated graph
plotGraph(gmfs[[1]])


###################################################
### chunk number 63: 
###################################################
#get degree of nodes
igraph::degree(gmfs[[1]],0)


###################################################
### chunk number 64: 
###################################################
#see name of the first node
V(gmfs[[1]])[0]$names


###################################################
### chunk number 65: 
###################################################
#get indexes of nodes
index1<-V(gmfs[[1]])[V(gmfs[[1]])$names=="ec:4.1.2.13"]
#get degree of node
igraph::degree(gmfs[[1]],index1)


###################################################
### chunk number 66: 
###################################################
#in-degree
igraph::degree(gmfs[[1]],index1,mode="in")
#out-degree
igraph::degree(gmfs[[1]],index1,mode="out")


###################################################
### chunk number 67: 
###################################################
#Calculate betweenness of enzyme "ec:4.1.2.13".
betweenness(gmfs[[1]],index1)


###################################################
### chunk number 68: 
###################################################
#Calculate the clustering coefficient of enzyme "ec:4.1.2.13".
igraph::transitivity(gmfs[[1]],type="local",vids=index1)


###################################################
### chunk number 69: 
###################################################
#Calculate the Closeness centrality of enzyme "ec:4.1.2.13".
closeness(gmfs[[1]],v=index1, mode = "all")
closeness(gmfs[[1]],v=index1, mode = "in")
closeness(gmfs[[1]],v=index1, mode = "out")


###################################################
### chunk number 70: 
###################################################
#get the shortest path
shortest.path<-get.shortest.paths(gmf[[1]],0,1,mode="out")


###################################################
### chunk number 71: 
###################################################
#see name of the first and second nodes
V(gmf[[1]])[0:1]$names
#see name of nodes in the shortest path
V(gmf[[1]])[shortest.path[[1]]]$names


###################################################
### chunk number 72: 
###################################################
#get indexes of nodes
index1<-V(gmf[[1]])[V(gmf[[1]])$names=="ec:4.1.2.13"]
index2<-V(gmf[[1]])[V(gmf[[1]])$names=="ec:1.2.1.3"]
#get shortest path
shortest.path<-get.shortest.paths(gmf[[1]],index1,index2)
#display shortest path
shortest.path
#convert indexs to names
V(gmf[[1]])[shortest.path[[1]]]$names


###################################################
### chunk number 73: 
###################################################
#degree distribution.
degree.distribution<-degree.distribution(gmfs[[1]])


###################################################
### chunk number 74: 
###################################################
#get diameter
diameter(gmfs[[1]])


###################################################
### chunk number 75: 
###################################################
#Calculate the clustering coefficient.
igraph::transitivity(gmfs[[1]])


###################################################
### chunk number 76: 
###################################################
#Calculate the density.
graph.density(gmfs[[1]])


###################################################
### chunk number 77: 
###################################################
#find modules.
wtc <- walktrap.community(gmfs[[1]])
module<-community.to.membership(gmfs[[1]], wtc$merges, steps=53)
module


###################################################
### chunk number 78: 
###################################################
V(gmfs[[1]])[module$membership==0]$names


###################################################
### chunk number 79: module
###################################################
vertex.color<-module$membership
vertex.color<-replace(vertex.color,which(vertex.color==0),"red")
vertex.color<-replace(vertex.color,which(vertex.color==1),"green")
vertex.color<-replace(vertex.color,which(vertex.color==2),"yellow")
plotGraph(gmfs[[1]],vertex.color=vertex.color)


###################################################
### chunk number 80: 
###################################################
modularity(gmfs[[1]], module$membership)


###################################################
### chunk number 81: 
###################################################
#get pathway graphs with enzymes as nodes.
graphList<-getMetabolicECECGraph()
#get a set of genes
geneList<-getExample(geneNumber=1000,compoundNumber=0)
#topology-based pathway analysis
ann<-identifyTopo(geneList,graphList,type="gene",propertyName="degree")
result<-printTopo(ann)
#print a part of the result
result[1:5,]


###################################################
### chunk number 82: 
###################################################
#list of the result
ann[1]


###################################################
### chunk number 83: TopologyPlotAnnGraphGene
###################################################
#visualize
plotAnnGraph("path:00562",graphList,ann)


###################################################
### chunk number 84: 
###################################################
ann<-identifyTopo(geneList,graphList,type="gene",
propertyName="degree",degree.mode="out")
result<-printTopo(ann)


###################################################
### chunk number 85: 
###################################################
#get undirected pathway graphs with genes as nodes.
graphList<-getMetabolicGEGEUEMGraph(type="EC")
#get a set of genes
geneList<-getExample(geneNumber=1000,compoundNumber=0)
#topology-based pathway analysis
ann<-identifyTopo(geneList,graphList,type="gene",propertyName="clusteringCoefficient")
result<-printTopo(ann)
#print a part of the result
result[1:10,c(1,3,6:8)]


###################################################
### chunk number 86: TopologyPlotAnnGraphGeneEM
###################################################
#visualize
plotAnnGraph("path:00010",graphList,ann,layout=layout.fruchterman.reingold)


###################################################
### chunk number 87: 
###################################################
#get metabolic pathway graphs with compounds as nodes. 
graphList<-getMetabolicCOCOGraph()
#get a set of compounds
compoundList<-getExample(geneNumber=0,compoundNumber=100)
#topology-based pathway analysis
ann<-identifyTopo(compoundList,graphList,type="compound",
propertyName="betweenness")
#data.frame
result<-printTopo(ann)
#print a part of the result
result[1:10,c(1,3,6:8)]


###################################################
### chunk number 88: TopologyPlotAnnGraphCompound
###################################################
#visualize
plotAnnGraph("path:00051",graphList,ann)


###################################################
### chunk number 89: 
###################################################
#get metabolic pathway graphs with enzymes and compounds as nodes. 
graphList<-getMetabolicECCOGraph()
#get a set of genes
componentList<-getExample(geneNumber=1000,compoundNumber=100)
#topology-based pathway analysis
ann<-identifyTopo(componentList,graphList,type="gene_compound",
propertyName="betweenness")
#data.frame
result<-printTopo(ann)
#print a part of the result
result[1:10,c(1,3,6:8)]


###################################################
### chunk number 90: TopologyPlotAnnGraphGeneCompound
###################################################
#visualize
plotAnnGraph("path:00010",graphList,ann)


###################################################
### chunk number 91: 
###################################################
##Convert all metabolic pathways to graphs.
metabolicEC<-get("metabolicEC",envir=k2ri)
graphList<-getMetabolicGraph(metabolicEC)


###################################################
### chunk number 92: 
###################################################
##get a set of genes
geneList<-getExample(geneNumber=1000)
#annotate gene sets to pathway graphs 
#and identify significant pathway graphs
ann<-identifyGraph(geneList,graphList)
#convert ann to data.frame
result<-printGraph(ann)
#print a part of the results to screen
result[1:10,]


###################################################
### chunk number 93: 
###################################################
#list of the result
ann[1]


###################################################
### chunk number 94: 
###################################################
result[result[,1] %in% "path:00010",]


###################################################
### chunk number 95: entirePlotAnnGraphGene
###################################################
#visualize
plotAnnGraph("path:00010",graphList,ann)


###################################################
### chunk number 96: 
###################################################
#get a set of compounds
compoundList<-getExample(geneNumber=0,compoundNumber=100)
#annotate compound sets and identify significant pathways
ann<-identifyGraph(compoundList,graphList,type="compound")
#convert ann to data.frame
result<-printGraph(ann)
#display a part of the result
result[1:10,c(1,3,4,5)]


###################################################
### chunk number 97: 
###################################################
result[result[,1] %in% "path:00010",]


###################################################
### chunk number 98: entirePlotAnnGraphCompound
###################################################
#visualize
plotAnnGraph("path:00010",graphList,ann)


###################################################
### chunk number 99: 
###################################################
#get a set of compounds and genes
componentList<-getExample(geneNumber=1000,compoundNumber=100)
#annotate gene and compound sets to metabolic graphs 
#and identify significant graphs
ann<-identifyGraph(componentList,graphList,type="gene_compound")
#convert ann to data.frame
result<-printGraph(ann)
#display a part of results
result[1:10,c(1,3,4,5)]


###################################################
### chunk number 100: 
###################################################
result[result[,1] %in% "path:00010",]


###################################################
### chunk number 101: entirePlotAnnGraphGeneCompound
###################################################
#visualize
plotAnnGraph("path:00010",graphList,ann)


###################################################
### chunk number 102: 
###################################################
##Convert all metabolic pathways to graphs.
metabolicKO<-get("metabolicKO",envir=k2ri)
gm<-getMetabolicGraph(metabolicKO)
##Convert all non-metabolic pathways to graphs, 
nonMetabolicKO<-get("nonMetabolicKO",envir=k2ri)
gn<-getNonMetabolicGraph(nonMetabolicKO)
graphList<-c(gm,gn)
##get a set of genes
geneList<-getExample(geneNumber=1000,compoundNumber=0)
#annotate gene sets and identify significant pathways
ann<-identifyGraph(geneList,graphList,type="gene")
result<-printGraph(ann)
#display part of results
result[1:10,c(1:5)]


###################################################
### chunk number 103: entirePlotAnnGraphKOMN
###################################################
#visualize
plotAnnGraph("path:04010",graphList,ann)


###################################################
### chunk number 104: 
###################################################
result[result[,1] %in% "path:04010",]


###################################################
### chunk number 105: 
###################################################
##Convert all metabolic pathways to graphs.
metabolicKO<-get("metabolicKO",envir=k2ri)
graphList<-getMetabolicGraph(metabolicKO)
##get a set of genes
geneList<-getExample(geneNumber=1000,compoundNumber=0)
#annotate gene sets and identify significant pathways
ann<-identifyGraph(geneList,graphList)
result<-printGraph(ann)
#display part of results
result[1:10,c(1,3,4,5)]


###################################################
### chunk number 106: 
###################################################
##identify metabolic subpathways based on gene sets
#get the enzyme-enzyme pathway graphs
graphList<-getMetabolicECECUGraph()
#get all 4-clique subgraphs
subGraphList<-getKcSubiGraph(k=4,graphList)
#get a set of genes
geneList<-getExample(geneNumber=1000,compoundNumber=0)
#annotate gene sets to subpathways 
#and identify significant graphs
ann<-identifyGraph(geneList,subGraphList,type="gene")
#convert ann to data.frame
result<-printGraph(ann)
#display a part of results
result[1:15,]


###################################################
### chunk number 107: 
###################################################
result[result[,1] %in% "path:00010_3",]


###################################################
### chunk number 108: kCliquePlotAnnGraphGene
###################################################
plotAnnGraph("path:00010_3",subGraphList,ann)


###################################################
### chunk number 109: 
###################################################
#visualize
plotAnnGraph("path:00010_3",subGraphList,ann,displayInR=FALSE,gotoKEGG=TRUE)


###################################################
### chunk number 110: 
###################################################
#get the compound-compound pathway graphs
graphList<-getMetabolicCOCOUGraph()
#get all 4-clique subgraphs
subGraphList<-getKcSubiGraph(k=4,graphList)
#get a set of compounds
compoundList<-getExample(geneNumber=0,compoundNumber=100)
#annotate compound sets and identify significant subpathways
ann<-identifyGraph(compoundList,subGraphList,type="compound")
#convert ann to data.frame
result<-printGraph(ann)
#display part of results
result[1:10,c(1,3,4,5)]


###################################################
### chunk number 111: 
###################################################
result[result[,1] %in% "path:00010_1",]


###################################################
### chunk number 112: kCliquePlotAnnGraphCompound
###################################################
plotAnnGraph("path:00010_1",subGraphList,ann)


###################################################
### chunk number 113: 
###################################################
graphList<-getMetabolicECCOUGraph()
#get all 8-clique subgraphs
subGraphList<-getKcSubiGraph(k=8,graphList)
#get a set of compounds and genes
componentList<-getExample(geneNumber=1000,compoundNumber=100)
#annotate gene and compound sets and identify significant subpathways
ann<-identifyGraph(componentList,subGraphList,type="gene_compound")
#convert ann to data.frame
result<-printGraph(ann)
#display part of results
result[1:15,c(1,3,4,5)]


###################################################
### chunk number 114: kCliquePlotAnnGraphGeneCompound
###################################################
plotAnnGraph("path:00010_3",subGraphList,ann)


###################################################
### chunk number 115: 
###################################################
result[result[,1] %in% "path:00010_3",]


###################################################
### chunk number 116: 
###################################################
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/metabolic/ec/",sep="")
gm<-getMetabolicGraph(getPathway(path,c("ec00010.xml")))


###################################################
### chunk number 117: keggStyle1
###################################################
#visualize
plotGraph(gm[[1]])


###################################################
### chunk number 118: metabolicSymbol
###################################################
plotGraph(gm[[1]],vertex.label=getNodeLabel(gm[[1]],
type="currentId",displayNumber=1))


###################################################
### chunk number 119: nonMetabolicSymbol
###################################################
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/non-metabolic/ko/",sep="")
gn<-getNonMetabolicGraph(getPathway(path,c("ko04010.xml")))
plotGraph(gn[[1]],vertex.label=getNodeLabel)


###################################################
### chunk number 120: nonMetabolicSymbolZoom
###################################################
plotGraph(gn[[1]],vertex.label=getNodeLabel,xlim=c(-1,-0.5),ylim=c(0,1))


###################################################
### chunk number 121: colorFrameGraphSet
###################################################
#add red frame to the enzyme "ec:4.1.2.13" 
vertex.frame.color<-ifelse(V(gm[[1]])$names=="ec:4.1.2.13","red","dimgray")
vertex.frame.color
#display new graph
plotGraph(gm[[1]],vertex.frame.color=vertex.frame.color)


###################################################
### chunk number 122: newGraphSet
###################################################
#add green label to the comound "cpd:C00111" 
vertex.label.color<-ifelse(V(gm[[1]])$names=="cpd:C00111","green","dimgray")
#change node color
vertex.color<-sapply(V(gm[[1]])$type,function(x) if(x=="enzyme"){"pink"}
else if(x=="compound"){"yellow"} else{"white"})
#change node size
size<-ifelse(V(gm[[1]])$graphics_name=="Starch and sucrose metabolism",20,8)
#change a compound label
#font size
vertex.label.cex<-ifelse(V(gm[[1]])$names=="cpd:C00036",1.0,0.6)
#italic
vertex.label.font<-ifelse(V(gm[[1]])$names=="cpd:C00036",3,1)
#change y coordinate of an enzyme
layout<-getLayout(gm[[1]])
index<-V(gm[[1]])[V(gm[[1]])$names=="ec:4.1.1.32"]
layout[index+1,2]<-layout[index+1,2]+50
#display the new graph 
plotGraph(gm[[1]],vertex.frame.color=vertex.frame.color,
vertex.label.color=vertex.label.color,vertex.color=vertex.color,
vertex.size=size,vertex.size2=size,vertex.label.cex=vertex.label.cex,
vertex.label.font=vertex.label.font,layout=layout)


###################################################
### chunk number 123: edgeColorGraph
###################################################
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/non-metabolic/ko/",sep="")
gn<-getNonMetabolicGraph(getPathway(path,c("ko04010.xml")))
#change color of edges with top 10% betweenness as red
eb<-edge.betweenness(gn[[1]])
edge.color<-ifelse(eb>quantile(eb,0.9),"red","dimgray")
plotGraph(gn[[1]],edge.color=edge.color)


###################################################
### chunk number 124: layoutrandom
###################################################
plotGraph(gm[[1]],layout=layout.random)


###################################################
### chunk number 125: layoutcircle
###################################################
plotGraph(gm[[1]],layout=layout.circle)


###################################################
### chunk number 126: 
###################################################
gm[[1]]$link
#link to KEGG
browseURL(gm[[1]]$link)


###################################################
### chunk number 127: 
###################################################
gn[[1]]$link
#link to KEGG
browseURL(gn[[1]]$link)


###################################################
### chunk number 128: 
###################################################
##Convert all metabolic pathways to graphs.
metabolicEC<-get("metabolicEC",envir=k2ri)
graphList<-getMetabolicGraph(metabolicEC)
##get a set of genes
geneList<-getExample(geneNumber=1000)
#annotate gene sets to pathway graphs 
#and identify significant pathway graphs
ann<-identifyGraph(geneList,graphList)


###################################################
### chunk number 129: entirePlotAnnGraphGeneV
###################################################
#visualize
plotAnnGraph("path:00010",graphList,ann)


###################################################
### chunk number 130: entirePlotAnnGraphGeneV
###################################################
#visualize
plotAnnGraph("path:00010",graphList,ann,gotoKEGG=TRUE)


###################################################
### chunk number 131: 
###################################################
write.graph(gm[[1]], "ec00010.txt", "gml")


###################################################
### chunk number 132: 
###################################################
##data in environment variable k2ri
ls(k2ri)


###################################################
### chunk number 133: 
###################################################
#get all metabolic pathway data
metabolicEC<-get("metabolicEC",envir=k2ri)


###################################################
### chunk number 134: 
###################################################
getOrgAndIdType()


###################################################
### chunk number 135:  eval=FALSE
###################################################
##  updateOrgAndIdType("sce","sgd-sce")


###################################################
### chunk number 136:  eval=FALSE
###################################################
## saveK2ri("sce_sgd-sce.rda")


###################################################
### chunk number 137:  eval=FALSE
###################################################
## loadK2ri("sce_sgd-sce.rda")


###################################################
### chunk number 138: sessionInfo
###################################################
sessionInfo()


